==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QCameraFlashControl_shell.h <==
#ifndef QCAMERAFLASHCONTROL_SHELL_H
#define QCAMERAFLASHCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcameraflashcontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QCameraFlashControl_shell : public QCameraFlashControl, public QtJambiShellInterface
{
public:
    QCameraFlashControl_shell(QObject* parent0 = nullptr);
    ~QCameraFlashControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QCameraExposure::FlashModes flashMode() const override;
    bool isFlashModeSupported(QCameraExposure::FlashModes mode0) const override;
    bool isFlashReady() const override;
    void setFlashMode(QCameraExposure::FlashModes mode0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraFlashControl_access : public QCameraFlashControl
{
    jint __qt_flashMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isFlashModeSupported_QCameraExposure_FlashModes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0) const;
    jboolean __qt_isFlashReady(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setFlashMode_QCameraExposure_FlashModes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
};

#endif // QCAMERAFLASHCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QCameraFlashControl_shell.h <==
#ifndef QCAMERAFLASHCONTROL_SHELL_H
#define QCAMERAFLASHCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qcameraflashcontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QCameraFlashControl_shell : public QCameraFlashControl, public QtJambiShellInterface
{
public:
    QCameraFlashControl_shell(QObject* parent0 = nullptr);
    ~QCameraFlashControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QCameraExposure::FlashModes flashMode() const override;
    bool isFlashModeSupported(QCameraExposure::FlashModes mode0) const override;
    bool isFlashReady() const override;
    void setFlashMode(QCameraExposure::FlashModes mode0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCameraFlashControl_access : public QCameraFlashControl
{
    jint __qt_flashMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isFlashModeSupported_QCameraExposure_FlashModes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0) const;
    jboolean __qt_isFlashReady_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setFlashMode_QCameraExposure_FlashModes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
};

#endif // QCAMERAFLASHCONTROL_SHELL_H
